'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _DependencyPath = require('./DependencyPath');

var _DependencyPath2 = _interopRequireDefault(_DependencyPath);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var SCOPE_NAME_VERSION_RE = /@(.+)\/(.*)@(.*)/;
var SCOPE_NAME_NO_VERSION_RE = /@(.+)\/(.+)/;
var NAME_VERSION_RE = /(.*)@(.*)/;

var Dependency = function () {
  function Dependency(name) {
    var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        scope = _ref.scope,
        version = _ref.version;

    _classCallCheck(this, Dependency);

    this.name = name;
    this.scope = scope;
    this.version = version;
  }

  _createClass(Dependency, [{
    key: 'withoutVersion',
    value: function withoutVersion() {
      return new Dependency(this.name, { scope: this.scope });
    }
  }, {
    key: 'toString',
    value: function toString() {
      return `${this.scope ? `@${this.scope}/` : ''}` + `${this.name}` + `${this.version ? `@${this.version}` : ''}`;
    }
  }, {
    key: 'path',
    get: function get() {
      return _DependencyPath2.default.fromString(this.toString());
    }
  }, {
    key: 'isVersioned',
    get: function get() {
      return this.version !== undefined;
    }
  }, {
    key: 'scopedName',
    get: function get() {
      return this.scope ? `@${this.scope}/${this.name}` : this.name;
    }
  }], [{
    key: 'fromObject',
    value: function fromObject(obj) {
      return new Dependency(obj.name, { scope: obj.scope, version: obj.version });
    }
  }, {
    key: 'fromString',
    value: function fromString(str) {
      if (SCOPE_NAME_VERSION_RE.test(str)) {
        var scopeNameVersion = SCOPE_NAME_VERSION_RE.exec(str);
        return new Dependency(scopeNameVersion[2], {
          scope: scopeNameVersion[1],
          version: scopeNameVersion[3]
        });
      } else if (SCOPE_NAME_NO_VERSION_RE.test(str)) {
        var scopeName = SCOPE_NAME_NO_VERSION_RE.exec(str);
        return new Dependency(scopeName[2], {
          scope: scopeName[1]
        });
      } else if (NAME_VERSION_RE.test(str)) {
        var nameVersion = NAME_VERSION_RE.exec(str);
        return new Dependency(nameVersion[1], {
          version: nameVersion[2]
        });
      } else {
        return new Dependency(str);
      }
    }
  }, {
    key: 'fromPath',
    value: function fromPath(path) {
      if (path.isAFileSystemPath || path.isAGitPath) {
        throw new Error('fromPath. File path or Git Path not yet supported');
      }
      return Dependency.fromString(path.toString());
    }
  }, {
    key: 'same',
    value: function same(depA, depB) {
      var _ref2 = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {},
          _ref2$ignoreVersion = _ref2.ignoreVersion,
          ignoreVersion = _ref2$ignoreVersion === undefined ? false : _ref2$ignoreVersion;

      return depA.name === depB.name && depA.scope === depB.scope && (ignoreVersion || depA.version === depB.version);
    }
  }]);

  return Dependency;
}();

exports.default = Dependency;
//# sourceMappingURL=Dependency.js.map